@@ -1,11 +1,19 @@
 /**************************************************************************
 * This file is part of the Fraqtive program
-* Copyright (C) 2004-2009 Michał Męciński
+* Copyright (C) 2004-2012 Michał Męciński
 *
-* This program is free software; you can redistribute it and/or modify
+* This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2 of the License, or
+* the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/
 
 #include "generatorcore.h"
@@ -644,14 +652,6 @@ inline void calculatePowerSSE2<1>( __m128d& /*zx*/, __m128d& /*zy*/, __m128d& /*
 {
 }
 
-#if Q_BYTE_ORDER == Q_LITTLE_ENDIAN
-static const quint32 SignMask[ 2 ] = { 0, 0x80000000 };
-static const quint32 NotSignMask[ 2 ] = { 0xffffffff, 0x7fffffff };
-#else
-static const quint32 SignMask[ 2 ] = { 0x80000000, 0 };
-static const quint32 NotSignMask[ 2 ] = { 0x7fffffff, 0xffffffff };
-#endif
-
 template<Variant VARIANT>
 static void adjustSSE2( __m128d& /*zx*/, __m128d& /*zy*/ );
 
@@ -663,14 +663,14 @@ inline void adjustSSE2<NormalVariant>( __m128d& /*zx*/, __m128d& /*zy*/ )
 template<>
 inline void adjustSSE2<ConjugateVariant>( __m128d& /*zx*/, __m128d& zy )
 {
-    __m128d mask = _mm_set1_pd( *(const double*)(const void*)SignMask );
+    __m128d mask = _mm_castsi128_pd( _mm_set_epi32( int( 0x80000000 ), 0, int( 0x80000000 ), 0 ) );
     zy = _mm_xor_pd( mask, zy );
 }
 
 template<>
 inline void adjustSSE2<AbsoluteVariant>( __m128d& zx, __m128d& zy )
 {
-    __m128d mask = _mm_set1_pd( *(const double*)(const void*)NotSignMask );
+    __m128d mask = _mm_castsi128_pd( _mm_set_epi32( 0x7fffffff, int( 0xffffffff ), 0x7fffffff, int( 0xffffffff ) ) );
     zx = _mm_and_pd( zx, mask );
     zy = _mm_and_pd( zy, mask );
 }
@@ -678,7 +678,7 @@ inline void adjustSSE2<AbsoluteVariant>( __m128d& zx, __m128d& zy )
 template<>
 inline void adjustSSE2<AbsoluteImVariant>( __m128d& /*zx*/, __m128d& zy )
 {
-    __m128d mask = _mm_set1_pd( *(const double*)(const void*)NotSignMask );
+    __m128d mask = _mm_castsi128_pd( _mm_set_epi32( 0x7fffffff, int( 0xffffffff ), 0x7fffffff, int( 0xffffffff ) ) );
     zy = _mm_and_pd( zy, mask );
 }
 
