@@ -1,11 +1,19 @@
 /**************************************************************************
 * This file is part of the Fraqtive program
-* Copyright (C) 2004-2009 Micha Mciski
+* Copyright (C) 2004-2012 Micha Mciski
 *
-* This program is free software; you can redistribute it and/or modify
+* This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2 of the License, or
+* the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/
 
 #include "loadbookmarkdialog.h"
@@ -17,12 +25,19 @@
 #include "fractalpresenter.h"
 #include "fractalmodel.h"
 #include "imageview.h"
+#include "iconloader.h"
 
 LoadBookmarkDialog::LoadBookmarkDialog( QWidget* parent ) : QDialog( parent ),
     m_model( NULL )
 {
     m_ui.setupUi( this );
 
+    m_ui.promptPixmap->setPixmap( IconLoader::pixmap( "load-bookmark", 22 ) );
+    m_ui.promptLabel->setText( tr( "Load fractal parameters from a bookmark:" ) );
+
+    m_ui.promptLabel->setMinimumWidth( 350 );
+    m_ui.promptLabel->setFixedHeight( m_ui.promptLabel->heightForWidth( 350 ) );
+
     m_ui.listView->setMap( fraqtive()->configuration()->bookmarks() );
 
     connect( m_ui.listView->selectionModel(), SIGNAL( selectionChanged( const QItemSelection&, const QItemSelection& ) ),
