@@ -1,11 +1,19 @@
 /**************************************************************************
 * This file is part of the Fraqtive program
-* Copyright (C) 2004-2008 Michał Męciński
+* Copyright (C) 2004-2012 Michał Męciński
 *
-* This program is free software; you can redistribute it and/or modify
+* This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2 of the License, or
+* the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/
 
 #include "propertytoolbox.h"
@@ -62,7 +70,7 @@ void PropertyToolBox::addPage( QWidget* page )
                 continue;
             QLabel* label = qobject_cast<QLabel*>( item->widget() );
             if ( label ) {
-                QString style = "border-bottom: 1px solid palette(dark);";
+                QString style = "border: none; border-bottom: 1px solid palette(dark);";
                 if ( i > 0 )
                     style += "margin-top: 2px;";
                 label->setStyleSheet( style );
@@ -81,5 +89,7 @@ void PropertyToolBox::addPage( QWidget* page )
         }
     }
 
+    page->setBackgroundRole( QPalette::Base );
+
     addItem( page, page->windowTitle() );
 }
