@@ -1,11 +1,19 @@
 /**************************************************************************
 * This file is part of the Fraqtive program
-* Copyright (C) 2004-2009 Micha Mciski
+* Copyright (C) 2004-2012 Micha Mciski
 *
-* This program is free software; you can redistribute it and/or modify
+* This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2 of the License, or
+* the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/
 
 #include "renamedialog.h"
@@ -13,34 +21,36 @@
 #include <QPushButton>
 #include <QMessageBox>
 
-RenameDialog::RenameDialog( QWidget* parent ) : QDialog( parent )
+#include "iconloader.h"
+
+RenameDialog::RenameDialog( Mode mode, const QString& name, QWidget* parent ) : QDialog( parent ),
+    m_mode( mode )
 {
     m_ui.setupUi( this );
 
-    setMaximumHeight( sizeHint().height() );
-}
-
-RenameDialog::~RenameDialog()
-{
-}
-
-void RenameDialog::setMode( Mode mode )
-{
-    m_mode = mode;
+    m_ui.promptPixmap->setPixmap( IconLoader::pixmap( "rename", 22 ) );
 
     switch ( mode ) {
         case PresetMode:
             setWindowTitle( tr( "Rename Preset" ) );
+            m_ui.promptLabel->setText( tr( "Rename preset <b>%1<b>:" ).arg( name ) );
             break;
         case BookmarkMode:
             setWindowTitle( tr( "Rename Bookmark" ) );
+            m_ui.promptLabel->setText( tr( "Rename bookmark <b>%1<b>:" ).arg( name ) );
             break;
     }
+
+    m_ui.promptLabel->setMinimumWidth( 350 );
+    m_ui.promptLabel->setFixedHeight( m_ui.promptLabel->heightForWidth( 350 ) );
+
+    setFixedHeight( sizeHint().height() );
+
+    m_ui.lineEdit->setText( name );
 }
 
-void RenameDialog::setName( const QString& name )
+RenameDialog::~RenameDialog()
 {
-    m_ui.lineEdit->setText( name );
 }
 
 QString RenameDialog::name() const
