@@ -1,11 +1,19 @@
 /**************************************************************************
 * This file is part of the Fraqtive program
-* Copyright (C) 2004-2009 Micha Mciski
+* Copyright (C) 2004-2012 Micha Mciski
 *
-* This program is free software; you can redistribute it and/or modify
+* This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2 of the License, or
+* the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/
 
 #include "savebookmarkdialog.h"
@@ -16,11 +24,18 @@
 #include "fraqtiveapplication.h"
 #include "configurationdata.h"
 #include "fractalmodel.h"
+#include "iconloader.h"
 
 SaveBookmarkDialog::SaveBookmarkDialog( QWidget* parent ) : QDialog( parent )
 {
     m_ui.setupUi( this );
 
+    m_ui.promptPixmap->setPixmap( IconLoader::pixmap( "save-bookmark", 22 ) );
+    m_ui.promptLabel->setText( tr( "Save fractal parameters as a bookmark:" ) );
+
+    m_ui.promptLabel->setMinimumWidth( 350 );
+    m_ui.promptLabel->setFixedHeight( m_ui.promptLabel->heightForWidth( 350 ) );
+
     connect( m_ui.listView->selectionModel(), SIGNAL( selectionChanged( const QItemSelection&, const QItemSelection& ) ),
         this, SLOT( selectionChanged() ) );
 
